[binutils-gdb] aarch64: Improve comment for aarch64_opnd_info.sysreg.flags
Alice Carlotti
acarlotti@sourceware.org
Thu Dec 4 16:24:31 GMT 2025
https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=7fc6ffb18e9845a7ee09cea829e4b2ba4475c0f0
commit 7fc6ffb18e9845a7ee09cea829e4b2ba4475c0f0
Author: Alice Carlotti <alice.carlotti@arm.com>
Date: Wed Nov 5 13:21:02 2025 +0000
aarch64: Improve comment for aarch64_opnd_info.sysreg.flags
This field is used differently during assembly and disassembly. It
would be nice if we could make this more consistent, but for now just
extend the comment to explain what is going on.
Diff:
---
include/opcode/aarch64.h | 4 +++-
1 file changed, 3 insertions(+), 1 deletion(-)
diff --git a/include/opcode/aarch64.h b/include/opcode/aarch64.h
index e65b61c3f9c..68a181c531f 100644
--- a/include/opcode/aarch64.h
+++ b/include/opcode/aarch64.h
@@ -1785,7 +1785,9 @@ struct aarch64_opnd_info
/* The encoding of the system register. */
aarch64_insn value;
- /* The system register flags. */
+ /* The system register flags. During assembly this contains the
+ flags from aarch64-sys-regs.def. During disassembly this stores
+ either F_REG_READ or F_REG_WRITE, depending upon the opcode. */
uint32_t flags;
} sysreg;
More information about the Binutils-cvs
mailing list